# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelpipeline/v1/modelpipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/modelpipeline/v1/modelpipeline.proto\x12\x37github.com.metaprov.modelaapi.services.modelpipeline.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\x86\x02\n\x19ListModelPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12n\n\x06labels\x18\x02 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x1aListModelPipelinesResponse\x12\x63\n\x0emodelpipelines\x18\x01 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15ModelPipelineResponse\"|\n\x1a\x43reateModelPipelineRequest\x12^\n\rmodelpipeline\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x1d\n\x1b\x43reateModelPipelineResponse\"\xac\x01\n\x1aUpdateModelPipelineRequest\x12^\n\rmodelpipeline\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateModelPipelineResponse\":\n\x17GetModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x88\x01\n\x18GetModelPipelineResponse\x12^\n\rmodelpipeline\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteModelPipelineResponse\"y\n\x17RunModelPipelineRequest\x12^\n\rmodelpipeline\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x1a\n\x18RunModelPipelineResponse\"\x1c\n\x1aPauseModelPipelineResponse\"<\n\x19PauseModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1bResumeModelPipelineResponse\"=\n\x1aResumeModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xb8\x0f\n\x14ModelPipelineService\x12\xe3\x01\n\x12ListModelPipelines\x12R.github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest\x1aS.github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1alpha1/modelpipelines\x12\xe9\x01\n\x13\x43reateModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/api/v1alpha1/modelpipelines:\x01*\x12\xe4\x01\n\x10GetModelPipeline\x12P.github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineRequest\x1aQ.github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineResponse\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1alpha1/modelpipelines/{name}\x12\x87\x02\n\x13UpdateModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineResponse\"E\x82\xd3\xe4\x93\x02?\x1a:/api/v1alpha1/modelpipelines/{modelpipeline.metadata.name}:\x01*\x12\xe7\x01\n\x13\x44\x65leteModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineResponse\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/api/v1/modelpipelines/{name}\x12\x9c\x02\n\x10RunModelPipeline\x12P.github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineRequest\x1aQ.github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineResponse\"c\x82\xd3\xe4\x93\x02]\"[/api/v1/modelpipelines/{modelpipeline.metadata.namespace}/{modelpipeline.metadata.name}:run\x12\xe6\x01\n\x12PauseModelPipeline\x12R.github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineRequest\x1aS.github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1f/v1/modelpipelines/{name}:pause\x12\xea\x01\n\x13ResumeModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineResponse\"(\x82\xd3\xe4\x93\x02\"\" /v1/modelpipelines/{name}:resumeB9Z7github.com/metaprov/modelaapi/services/modelpipeline/v1b\x06proto3')



_LISTMODELPIPELINESREQUEST = DESCRIPTOR.message_types_by_name['ListModelPipelinesRequest']
_LISTMODELPIPELINESREQUEST_LABELSENTRY = _LISTMODELPIPELINESREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELPIPELINESRESPONSE = DESCRIPTOR.message_types_by_name['ListModelPipelinesResponse']
_MODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ModelPipelineResponse']
_CREATEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateModelPipelineRequest']
_CREATEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['CreateModelPipelineResponse']
_UPDATEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelPipelineRequest']
_UPDATEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelPipelineResponse']
_GETMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetModelPipelineRequest']
_GETMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['GetModelPipelineResponse']
_DELETEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelPipelineRequest']
_DELETEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelPipelineResponse']
_RUNMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['RunModelPipelineRequest']
_RUNMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['RunModelPipelineResponse']
_PAUSEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['PauseModelPipelineResponse']
_PAUSEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['PauseModelPipelineRequest']
_RESUMEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ResumeModelPipelineResponse']
_RESUMEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ResumeModelPipelineRequest']
ListModelPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListModelPipelinesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELPIPELINESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest)
  })
_sym_db.RegisterMessage(ListModelPipelinesRequest)
_sym_db.RegisterMessage(ListModelPipelinesRequest.LabelsEntry)

ListModelPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListModelPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesResponse)
  })
_sym_db.RegisterMessage(ListModelPipelinesResponse)

ModelPipelineResponse = _reflection.GeneratedProtocolMessageType('ModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineResponse)
  })
_sym_db.RegisterMessage(ModelPipelineResponse)

CreateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineRequest)
  })
_sym_db.RegisterMessage(CreateModelPipelineRequest)

CreateModelPipelineResponse = _reflection.GeneratedProtocolMessageType('CreateModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineResponse)
  })
_sym_db.RegisterMessage(CreateModelPipelineResponse)

UpdateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRequest)

UpdateModelPipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineResponse)
  })
_sym_db.RegisterMessage(UpdateModelPipelineResponse)

GetModelPipelineRequest = _reflection.GeneratedProtocolMessageType('GetModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineRequest)
  })
_sym_db.RegisterMessage(GetModelPipelineRequest)

GetModelPipelineResponse = _reflection.GeneratedProtocolMessageType('GetModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineResponse)
  })
_sym_db.RegisterMessage(GetModelPipelineResponse)

DeleteModelPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRequest)

DeleteModelPipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineResponse)
  })
_sym_db.RegisterMessage(DeleteModelPipelineResponse)

RunModelPipelineRequest = _reflection.GeneratedProtocolMessageType('RunModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineRequest)
  })
_sym_db.RegisterMessage(RunModelPipelineRequest)

RunModelPipelineResponse = _reflection.GeneratedProtocolMessageType('RunModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineResponse)
  })
_sym_db.RegisterMessage(RunModelPipelineResponse)

PauseModelPipelineResponse = _reflection.GeneratedProtocolMessageType('PauseModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineResponse)
  })
_sym_db.RegisterMessage(PauseModelPipelineResponse)

PauseModelPipelineRequest = _reflection.GeneratedProtocolMessageType('PauseModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineRequest)
  })
_sym_db.RegisterMessage(PauseModelPipelineRequest)

ResumeModelPipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineResponse)
  })
_sym_db.RegisterMessage(ResumeModelPipelineResponse)

ResumeModelPipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineRequest)
  })
_sym_db.RegisterMessage(ResumeModelPipelineRequest)

_MODELPIPELINESERVICE = DESCRIPTOR.services_by_name['ModelPipelineService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/modelpipeline/v1'
  _LISTMODELPIPELINESREQUEST_LABELSENTRY._options = None
  _LISTMODELPIPELINESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELPIPELINESERVICE.methods_by_name['ListModelPipelines']._options = None
  _MODELPIPELINESERVICE.methods_by_name['ListModelPipelines']._serialized_options = b'\202\323\344\223\002\036\022\034/api/v1alpha1/modelpipelines'
  _MODELPIPELINESERVICE.methods_by_name['CreateModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['CreateModelPipeline']._serialized_options = b'\202\323\344\223\002!\"\034/api/v1alpha1/modelpipelines:\001*'
  _MODELPIPELINESERVICE.methods_by_name['GetModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['GetModelPipeline']._serialized_options = b'\202\323\344\223\002%\022#/api/v1alpha1/modelpipelines/{name}'
  _MODELPIPELINESERVICE.methods_by_name['UpdateModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['UpdateModelPipeline']._serialized_options = b'\202\323\344\223\002?\032:/api/v1alpha1/modelpipelines/{modelpipeline.metadata.name}:\001*'
  _MODELPIPELINESERVICE.methods_by_name['DeleteModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['DeleteModelPipeline']._serialized_options = b'\202\323\344\223\002\037*\035/api/v1/modelpipelines/{name}'
  _MODELPIPELINESERVICE.methods_by_name['RunModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['RunModelPipeline']._serialized_options = b'\202\323\344\223\002]\"[/api/v1/modelpipelines/{modelpipeline.metadata.namespace}/{modelpipeline.metadata.name}:run'
  _MODELPIPELINESERVICE.methods_by_name['PauseModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['PauseModelPipeline']._serialized_options = b'\202\323\344\223\002!\"\037/v1/modelpipelines/{name}:pause'
  _MODELPIPELINESERVICE.methods_by_name['ResumeModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['ResumeModelPipeline']._serialized_options = b'\202\323\344\223\002\"\" /v1/modelpipelines/{name}:resume'
  _LISTMODELPIPELINESREQUEST._serialized_start=275
  _LISTMODELPIPELINESREQUEST._serialized_end=537
  _LISTMODELPIPELINESREQUEST_LABELSENTRY._serialized_start=492
  _LISTMODELPIPELINESREQUEST_LABELSENTRY._serialized_end=537
  _LISTMODELPIPELINESRESPONSE._serialized_start=540
  _LISTMODELPIPELINESRESPONSE._serialized_end=694
  _MODELPIPELINERESPONSE._serialized_start=696
  _MODELPIPELINERESPONSE._serialized_end=719
  _CREATEMODELPIPELINEREQUEST._serialized_start=721
  _CREATEMODELPIPELINEREQUEST._serialized_end=845
  _CREATEMODELPIPELINERESPONSE._serialized_start=847
  _CREATEMODELPIPELINERESPONSE._serialized_end=876
  _UPDATEMODELPIPELINEREQUEST._serialized_start=879
  _UPDATEMODELPIPELINEREQUEST._serialized_end=1051
  _UPDATEMODELPIPELINERESPONSE._serialized_start=1053
  _UPDATEMODELPIPELINERESPONSE._serialized_end=1082
  _GETMODELPIPELINEREQUEST._serialized_start=1084
  _GETMODELPIPELINEREQUEST._serialized_end=1142
  _GETMODELPIPELINERESPONSE._serialized_start=1145
  _GETMODELPIPELINERESPONSE._serialized_end=1281
  _DELETEMODELPIPELINEREQUEST._serialized_start=1283
  _DELETEMODELPIPELINEREQUEST._serialized_end=1344
  _DELETEMODELPIPELINERESPONSE._serialized_start=1346
  _DELETEMODELPIPELINERESPONSE._serialized_end=1375
  _RUNMODELPIPELINEREQUEST._serialized_start=1377
  _RUNMODELPIPELINEREQUEST._serialized_end=1498
  _RUNMODELPIPELINERESPONSE._serialized_start=1500
  _RUNMODELPIPELINERESPONSE._serialized_end=1526
  _PAUSEMODELPIPELINERESPONSE._serialized_start=1528
  _PAUSEMODELPIPELINERESPONSE._serialized_end=1556
  _PAUSEMODELPIPELINEREQUEST._serialized_start=1558
  _PAUSEMODELPIPELINEREQUEST._serialized_end=1618
  _RESUMEMODELPIPELINERESPONSE._serialized_start=1620
  _RESUMEMODELPIPELINERESPONSE._serialized_end=1649
  _RESUMEMODELPIPELINEREQUEST._serialized_start=1651
  _RESUMEMODELPIPELINEREQUEST._serialized_end=1712
  _MODELPIPELINESERVICE._serialized_start=1715
  _MODELPIPELINESERVICE._serialized_end=3691
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto\x12\x31github.com.metaprov.modelaapi.services.dataapp.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xf4\x01\n\x13ListDataAppsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x14ListDataAppsResponse\x12X\n\x08\x64\x61taapps\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataAppList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15\x43reateDataAppResponse\"k\n\x14\x43reateDataAppRequest\x12S\n\x07\x64\x61taapp\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x9b\x01\n\x14UpdateDataAppRequest\x12S\n\x07\x64\x61taapp\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x17\n\x15UpdateDataAppResponse\"4\n\x11GetDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"w\n\x12GetDataAppResponse\x12S\n\x07\x64\x61taapp\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteDataAppResponse\"6\n\x13PauseDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14PauseDataAppResponse\"7\n\x14ResumeDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15ResumeDataAppResponse\"h\n\x11RunDataAppRequest\x12S\n\x07\x64\x61taapp\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x14\n\x12RunDataAppResponse2\xa9\r\n\x0e\x44\x61taAppService\x12\xc1\x01\n\x0cListDataApps\x12\x46.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest\x1aG.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/dataapps/{namespace}\x12\xbb\x01\n\rCreateDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/dataapps:\x01*\x12\xc2\x01\n\nGetDataApp\x12\x44.github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/dataapps/{namespace}/{name}\x12\xf0\x01\n\rUpdateDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse\"L\x82\xd3\xe4\x93\x02\x46\x1a\x41/v1/dataapps/{dataapp.metadata.namespace}/{dataapp.metadata.name}:\x01*\x12\xcb\x01\n\rDeleteDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/dataapps/{namespace}/{name}\x12\xce\x01\n\x0cPauseDataApp\x12\x46.github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest\x1aG.github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse\"-\x82\xd3\xe4\x93\x02\'\"%/v1/dataapps/{namespace}/{name}:pause\x12\xe8\x01\n\nRunDataApp\x12\x44.github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppResponse\"M\x82\xd3\xe4\x93\x02G\"E/v1/dataapps/{dataapp.metadata.namespace}/{dataapp.metadata.name}:run\x12\xd2\x01\n\rResumeDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse\".\x82\xd3\xe4\x93\x02(\"&/v1/dataapps/{namespace}/{name}:resumeB3Z1github.com/metaprov/modelaapi/services/dataapp/v1b\x06proto3')



_LISTDATAAPPSREQUEST = DESCRIPTOR.message_types_by_name['ListDataAppsRequest']
_LISTDATAAPPSREQUEST_LABELSENTRY = _LISTDATAAPPSREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATAAPPSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataAppsResponse']
_CREATEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataAppResponse']
_CREATEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['CreateDataAppRequest']
_UPDATEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataAppRequest']
_UPDATEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataAppResponse']
_GETDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['GetDataAppRequest']
_GETDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['GetDataAppResponse']
_DELETEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataAppRequest']
_DELETEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataAppResponse']
_PAUSEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['PauseDataAppRequest']
_PAUSEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['PauseDataAppResponse']
_RESUMEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['ResumeDataAppRequest']
_RESUMEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['ResumeDataAppResponse']
_RUNDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['RunDataAppRequest']
_RUNDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['RunDataAppResponse']
ListDataAppsRequest = _reflection.GeneratedProtocolMessageType('ListDataAppsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAAPPSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAAPPSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest)
  })
_sym_db.RegisterMessage(ListDataAppsRequest)
_sym_db.RegisterMessage(ListDataAppsRequest.LabelsEntry)

ListDataAppsResponse = _reflection.GeneratedProtocolMessageType('ListDataAppsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAAPPSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse)
  })
_sym_db.RegisterMessage(ListDataAppsResponse)

CreateDataAppResponse = _reflection.GeneratedProtocolMessageType('CreateDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse)
  })
_sym_db.RegisterMessage(CreateDataAppResponse)

CreateDataAppRequest = _reflection.GeneratedProtocolMessageType('CreateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest)
  })
_sym_db.RegisterMessage(CreateDataAppRequest)

UpdateDataAppRequest = _reflection.GeneratedProtocolMessageType('UpdateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest)
  })
_sym_db.RegisterMessage(UpdateDataAppRequest)

UpdateDataAppResponse = _reflection.GeneratedProtocolMessageType('UpdateDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse)
  })
_sym_db.RegisterMessage(UpdateDataAppResponse)

GetDataAppRequest = _reflection.GeneratedProtocolMessageType('GetDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest)
  })
_sym_db.RegisterMessage(GetDataAppRequest)

GetDataAppResponse = _reflection.GeneratedProtocolMessageType('GetDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse)
  })
_sym_db.RegisterMessage(GetDataAppResponse)

DeleteDataAppRequest = _reflection.GeneratedProtocolMessageType('DeleteDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest)
  })
_sym_db.RegisterMessage(DeleteDataAppRequest)

DeleteDataAppResponse = _reflection.GeneratedProtocolMessageType('DeleteDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse)
  })
_sym_db.RegisterMessage(DeleteDataAppResponse)

PauseDataAppRequest = _reflection.GeneratedProtocolMessageType('PauseDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest)
  })
_sym_db.RegisterMessage(PauseDataAppRequest)

PauseDataAppResponse = _reflection.GeneratedProtocolMessageType('PauseDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse)
  })
_sym_db.RegisterMessage(PauseDataAppResponse)

ResumeDataAppRequest = _reflection.GeneratedProtocolMessageType('ResumeDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest)
  })
_sym_db.RegisterMessage(ResumeDataAppRequest)

ResumeDataAppResponse = _reflection.GeneratedProtocolMessageType('ResumeDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse)
  })
_sym_db.RegisterMessage(ResumeDataAppResponse)

RunDataAppRequest = _reflection.GeneratedProtocolMessageType('RunDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest)
  })
_sym_db.RegisterMessage(RunDataAppRequest)

RunDataAppResponse = _reflection.GeneratedProtocolMessageType('RunDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppResponse)
  })
_sym_db.RegisterMessage(RunDataAppResponse)

_DATAAPPSERVICE = DESCRIPTOR.services_by_name['DataAppService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/dataapp/v1'
  _LISTDATAAPPSREQUEST_LABELSENTRY._options = None
  _LISTDATAAPPSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATAAPPSERVICE.methods_by_name['ListDataApps']._options = None
  _DATAAPPSERVICE.methods_by_name['ListDataApps']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/dataapps/{namespace}'
  _DATAAPPSERVICE.methods_by_name['CreateDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['CreateDataApp']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/dataapps:\001*'
  _DATAAPPSERVICE.methods_by_name['GetDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['GetDataApp']._serialized_options = b'\202\323\344\223\002!\022\037/v1/dataapps/{namespace}/{name}'
  _DATAAPPSERVICE.methods_by_name['UpdateDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['UpdateDataApp']._serialized_options = b'\202\323\344\223\002F\032A/v1/dataapps/{dataapp.metadata.namespace}/{dataapp.metadata.name}:\001*'
  _DATAAPPSERVICE.methods_by_name['DeleteDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['DeleteDataApp']._serialized_options = b'\202\323\344\223\002!*\037/v1/dataapps/{namespace}/{name}'
  _DATAAPPSERVICE.methods_by_name['PauseDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['PauseDataApp']._serialized_options = b'\202\323\344\223\002\'\"%/v1/dataapps/{namespace}/{name}:pause'
  _DATAAPPSERVICE.methods_by_name['RunDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['RunDataApp']._serialized_options = b'\202\323\344\223\002G\"E/v1/dataapps/{dataapp.metadata.namespace}/{dataapp.metadata.name}:run'
  _DATAAPPSERVICE.methods_by_name['ResumeDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['ResumeDataApp']._serialized_options = b'\202\323\344\223\002(\"&/v1/dataapps/{namespace}/{name}:resume'
  _LISTDATAAPPSREQUEST._serialized_start=258
  _LISTDATAAPPSREQUEST._serialized_end=502
  _LISTDATAAPPSREQUEST_LABELSENTRY._serialized_start=457
  _LISTDATAAPPSREQUEST_LABELSENTRY._serialized_end=502
  _LISTDATAAPPSRESPONSE._serialized_start=505
  _LISTDATAAPPSRESPONSE._serialized_end=642
  _CREATEDATAAPPRESPONSE._serialized_start=644
  _CREATEDATAAPPRESPONSE._serialized_end=667
  _CREATEDATAAPPREQUEST._serialized_start=669
  _CREATEDATAAPPREQUEST._serialized_end=776
  _UPDATEDATAAPPREQUEST._serialized_start=779
  _UPDATEDATAAPPREQUEST._serialized_end=934
  _UPDATEDATAAPPRESPONSE._serialized_start=936
  _UPDATEDATAAPPRESPONSE._serialized_end=959
  _GETDATAAPPREQUEST._serialized_start=961
  _GETDATAAPPREQUEST._serialized_end=1013
  _GETDATAAPPRESPONSE._serialized_start=1015
  _GETDATAAPPRESPONSE._serialized_end=1134
  _DELETEDATAAPPREQUEST._serialized_start=1136
  _DELETEDATAAPPREQUEST._serialized_end=1191
  _DELETEDATAAPPRESPONSE._serialized_start=1193
  _DELETEDATAAPPRESPONSE._serialized_end=1216
  _PAUSEDATAAPPREQUEST._serialized_start=1218
  _PAUSEDATAAPPREQUEST._serialized_end=1272
  _PAUSEDATAAPPRESPONSE._serialized_start=1274
  _PAUSEDATAAPPRESPONSE._serialized_end=1296
  _RESUMEDATAAPPREQUEST._serialized_start=1298
  _RESUMEDATAAPPREQUEST._serialized_end=1353
  _RESUMEDATAAPPRESPONSE._serialized_start=1355
  _RESUMEDATAAPPRESPONSE._serialized_end=1378
  _RUNDATAAPPREQUEST._serialized_start=1380
  _RUNDATAAPPREQUEST._serialized_end=1484
  _RUNDATAAPPRESPONSE._serialized_start=1486
  _RUNDATAAPPRESPONSE._serialized_end=1506
  _DATAAPPSERVICE._serialized_start=1509
  _DATAAPPSERVICE._serialized_end=3214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/sqlquery/v1/sqlquery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAgithub.com/metaprov/modelaapi/services/sqlquery/v1/sqlquery.proto\x12\x32github.com.metaprov.modelaapi.services.sqlquery.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xcc\x01\n\x14ListSqlQuerysRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x64\n\x06labels\x18\x03 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n\x15ListSqlQuerysResponse\x12U\n\tsqlquries\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x18\n\x16\x43reateSqlQueryResponse\"i\n\x15\x43reateSqlQueryRequest\x12P\n\x08sqlquery\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"\x99\x01\n\x15UpdateSqlQueryRequest\x12P\n\x08sqlquery\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x18\n\x16UpdateSqlQueryResponse\"5\n\x12GetSqlQueryRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x13GetSqlQueryResponse\x12P\n\x08sqlquery\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"8\n\x15\x44\x65leteSqlQueryRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteSqlQueryResponse\"f\n\x12RunSqlQueryRequest\x12P\n\x08sqlquery\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQuery\"\x15\n\x13RunSqlQueryResponse2\xb2\n\n\x0fSqlQueryService\x12\xc8\x01\n\rListSqlQuerys\x12H.github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest\x1aI.github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/sqlqueries/{namespace}\x12\xc2\x01\n\x0e\x43reateSqlQuery\x12I.github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryRequest\x1aJ.github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/sqlqueries:\x01*\x12\xc9\x01\n\x0bGetSqlQuery\x12\x46.github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryRequest\x1aG.github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/sqlqueries/{namespace}/{name}\x12\xf9\x01\n\x0eUpdateSqlQuery\x12I.github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryRequest\x1aJ.github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryResponse\"P\x82\xd3\xe4\x93\x02J\x1a\x45/v1/sqlqueries/{sqlquery.metadata.namespace}/{sqlquery.metadata.name}:\x01*\x12\xd2\x01\n\x0e\x44\x65leteSqlQuery\x12I.github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryRequest\x1aJ.github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryResponse\")\x82\xd3\xe4\x93\x02#*!/v1/sqlqueries/{namespace}/{name}\x12\xf1\x01\n\x0bRunSqlQuery\x12\x46.github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryRequest\x1aG.github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryResponse\"Q\x82\xd3\xe4\x93\x02K\"I/v1/sqlqueries/{sqlquery.metadata.namespace}/{sqlquery.metadata.name}:runB4Z2github.com/metaprov/modelaapi/services/sqlquery/v1b\x06proto3')



_LISTSQLQUERYSREQUEST = DESCRIPTOR.message_types_by_name['ListSqlQuerysRequest']
_LISTSQLQUERYSREQUEST_LABELSENTRY = _LISTSQLQUERYSREQUEST.nested_types_by_name['LabelsEntry']
_LISTSQLQUERYSRESPONSE = DESCRIPTOR.message_types_by_name['ListSqlQuerysResponse']
_CREATESQLQUERYRESPONSE = DESCRIPTOR.message_types_by_name['CreateSqlQueryResponse']
_CREATESQLQUERYREQUEST = DESCRIPTOR.message_types_by_name['CreateSqlQueryRequest']
_UPDATESQLQUERYREQUEST = DESCRIPTOR.message_types_by_name['UpdateSqlQueryRequest']
_UPDATESQLQUERYRESPONSE = DESCRIPTOR.message_types_by_name['UpdateSqlQueryResponse']
_GETSQLQUERYREQUEST = DESCRIPTOR.message_types_by_name['GetSqlQueryRequest']
_GETSQLQUERYRESPONSE = DESCRIPTOR.message_types_by_name['GetSqlQueryResponse']
_DELETESQLQUERYREQUEST = DESCRIPTOR.message_types_by_name['DeleteSqlQueryRequest']
_DELETESQLQUERYRESPONSE = DESCRIPTOR.message_types_by_name['DeleteSqlQueryResponse']
_RUNSQLQUERYREQUEST = DESCRIPTOR.message_types_by_name['RunSqlQueryRequest']
_RUNSQLQUERYRESPONSE = DESCRIPTOR.message_types_by_name['RunSqlQueryResponse']
ListSqlQuerysRequest = _reflection.GeneratedProtocolMessageType('ListSqlQuerysRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSQLQUERYSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSQLQUERYSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysRequest)
  })
_sym_db.RegisterMessage(ListSqlQuerysRequest)
_sym_db.RegisterMessage(ListSqlQuerysRequest.LabelsEntry)

ListSqlQuerysResponse = _reflection.GeneratedProtocolMessageType('ListSqlQuerysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSQLQUERYSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.ListSqlQuerysResponse)
  })
_sym_db.RegisterMessage(ListSqlQuerysResponse)

CreateSqlQueryResponse = _reflection.GeneratedProtocolMessageType('CreateSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryResponse)
  })
_sym_db.RegisterMessage(CreateSqlQueryResponse)

CreateSqlQueryRequest = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.CreateSqlQueryRequest)
  })
_sym_db.RegisterMessage(CreateSqlQueryRequest)

UpdateSqlQueryRequest = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryRequest)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRequest)

UpdateSqlQueryResponse = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.UpdateSqlQueryResponse)
  })
_sym_db.RegisterMessage(UpdateSqlQueryResponse)

GetSqlQueryRequest = _reflection.GeneratedProtocolMessageType('GetSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryRequest)
  })
_sym_db.RegisterMessage(GetSqlQueryRequest)

GetSqlQueryResponse = _reflection.GeneratedProtocolMessageType('GetSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.GetSqlQueryResponse)
  })
_sym_db.RegisterMessage(GetSqlQueryResponse)

DeleteSqlQueryRequest = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryRequest)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRequest)

DeleteSqlQueryResponse = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.DeleteSqlQueryResponse)
  })
_sym_db.RegisterMessage(DeleteSqlQueryResponse)

RunSqlQueryRequest = _reflection.GeneratedProtocolMessageType('RunSqlQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryRequest)
  })
_sym_db.RegisterMessage(RunSqlQueryRequest)

RunSqlQueryResponse = _reflection.GeneratedProtocolMessageType('RunSqlQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlquery.v1.sqlquery_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlquery.v1.RunSqlQueryResponse)
  })
_sym_db.RegisterMessage(RunSqlQueryResponse)

_SQLQUERYSERVICE = DESCRIPTOR.services_by_name['SqlQueryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/metaprov/modelaapi/services/sqlquery/v1'
  _LISTSQLQUERYSREQUEST_LABELSENTRY._options = None
  _LISTSQLQUERYSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _SQLQUERYSERVICE.methods_by_name['ListSqlQuerys']._options = None
  _SQLQUERYSERVICE.methods_by_name['ListSqlQuerys']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/sqlqueries/{namespace}'
  _SQLQUERYSERVICE.methods_by_name['CreateSqlQuery']._options = None
  _SQLQUERYSERVICE.methods_by_name['CreateSqlQuery']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/sqlqueries:\001*'
  _SQLQUERYSERVICE.methods_by_name['GetSqlQuery']._options = None
  _SQLQUERYSERVICE.methods_by_name['GetSqlQuery']._serialized_options = b'\202\323\344\223\002#\022!/v1/sqlqueries/{namespace}/{name}'
  _SQLQUERYSERVICE.methods_by_name['UpdateSqlQuery']._options = None
  _SQLQUERYSERVICE.methods_by_name['UpdateSqlQuery']._serialized_options = b'\202\323\344\223\002J\032E/v1/sqlqueries/{sqlquery.metadata.namespace}/{sqlquery.metadata.name}:\001*'
  _SQLQUERYSERVICE.methods_by_name['DeleteSqlQuery']._options = None
  _SQLQUERYSERVICE.methods_by_name['DeleteSqlQuery']._serialized_options = b'\202\323\344\223\002#*!/v1/sqlqueries/{namespace}/{name}'
  _SQLQUERYSERVICE.methods_by_name['RunSqlQuery']._options = None
  _SQLQUERYSERVICE.methods_by_name['RunSqlQuery']._serialized_options = b'\202\323\344\223\002K\"I/v1/sqlqueries/{sqlquery.metadata.namespace}/{sqlquery.metadata.name}:run'
  _LISTSQLQUERYSREQUEST._serialized_start=256
  _LISTSQLQUERYSREQUEST._serialized_end=460
  _LISTSQLQUERYSREQUEST_LABELSENTRY._serialized_start=415
  _LISTSQLQUERYSREQUEST_LABELSENTRY._serialized_end=460
  _LISTSQLQUERYSRESPONSE._serialized_start=463
  _LISTSQLQUERYSRESPONSE._serialized_end=598
  _CREATESQLQUERYRESPONSE._serialized_start=600
  _CREATESQLQUERYRESPONSE._serialized_end=624
  _CREATESQLQUERYREQUEST._serialized_start=626
  _CREATESQLQUERYREQUEST._serialized_end=731
  _UPDATESQLQUERYREQUEST._serialized_start=734
  _UPDATESQLQUERYREQUEST._serialized_end=887
  _UPDATESQLQUERYRESPONSE._serialized_start=889
  _UPDATESQLQUERYRESPONSE._serialized_end=913
  _GETSQLQUERYREQUEST._serialized_start=915
  _GETSQLQUERYREQUEST._serialized_end=968
  _GETSQLQUERYRESPONSE._serialized_start=970
  _GETSQLQUERYRESPONSE._serialized_end=1087
  _DELETESQLQUERYREQUEST._serialized_start=1089
  _DELETESQLQUERYREQUEST._serialized_end=1145
  _DELETESQLQUERYRESPONSE._serialized_start=1147
  _DELETESQLQUERYRESPONSE._serialized_end=1171
  _RUNSQLQUERYREQUEST._serialized_start=1173
  _RUNSQLQUERYREQUEST._serialized_end=1275
  _RUNSQLQUERYRESPONSE._serialized_start=1277
  _RUNSQLQUERYRESPONSE._serialized_end=1298
  _SQLQUERYSERVICE._serialized_start=1301
  _SQLQUERYSERVICE._serialized_end=2631
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.dataapp.v1 import dataapp_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2


class DataAppServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataApps = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/ListDataApps',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsResponse.FromString,
                )
        self.CreateDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/CreateDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppResponse.FromString,
                )
        self.GetDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/GetDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppResponse.FromString,
                )
        self.UpdateDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/UpdateDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppResponse.FromString,
                )
        self.DeleteDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/DeleteDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppResponse.FromString,
                )
        self.PauseDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/PauseDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppResponse.FromString,
                )
        self.RunDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/RunDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppResponse.FromString,
                )
        self.ResumeDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/ResumeDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppResponse.FromString,
                )


class DataAppServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataApps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataAppServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataApps': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataApps,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsResponse.SerializeToString,
            ),
            'CreateDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppResponse.SerializeToString,
            ),
            'GetDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppResponse.SerializeToString,
            ),
            'UpdateDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppResponse.SerializeToString,
            ),
            'DeleteDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppResponse.SerializeToString,
            ),
            'PauseDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppResponse.SerializeToString,
            ),
            'RunDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.RunDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppResponse.SerializeToString,
            ),
            'ResumeDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataAppService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/ListDataApps',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/CreateDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/GetDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/UpdateDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/DeleteDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/PauseDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/RunDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/ResumeDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
